@@ -129,6 +129,7 @@ var (
 	GrafanaServiceAccount       = "assets/grafana/service-account.yaml"
 	GrafanaService              = "assets/grafana/service.yaml"
 	GrafanaServiceMonitor       = "assets/grafana/service-monitor.yaml"
+	GrafanaTrustedCABundle      = "assets/grafana/trusted-ca-bundle.yaml"
 
 	ClusterMonitoringOperatorService        = "assets/cluster-monitoring-operator/service.yaml"
 	ClusterMonitoringOperatorServiceMonitor = "assets/cluster-monitoring-operator/service-monitor.yaml"
@@ -514,6 +515,7 @@ func (f *Factory) NodeExporterDaemonSet() (*appsv1.DaemonSet, error) {
 		return nil, err
 	}
 
+	ds.Spec.Template.Spec.InitContainers[0].Image = f.config.Images.NodeExporter
 	ds.Spec.Template.Spec.Containers[0].Image = f.config.Images.NodeExporter
 	ds.Spec.Template.Spec.Containers[1].Image = f.config.Images.KubeRbacProxy
 
@@ -1325,7 +1327,19 @@ func (f *Factory) GrafanaDashboardSources() (*v1.ConfigMap, error) {
 	return c, nil
 }
 
-func (f *Factory) GrafanaDeployment() (*appsv1.Deployment, error) {
+func (f *Factory) GrafanaTrustedCABundle() (*v1.ConfigMap, error) {
+	cm, err := f.NewConfigMap(MustAssetReader(GrafanaTrustedCABundle))
+	if err != nil {
+		return nil, err
+	}
+
+	return cm, nil
+}
+
+// GrafanaDeployment generates a new Deployment for Grafana.
+// If the passed ConfigMap is not empty it mounts the Trusted CA Bundle as a VolumeMount to
+// /etc/pki/ca-trust/extracted/pem/ location.
+func (f *Factory) GrafanaDeployment(proxyCABundleCM *v1.ConfigMap) (*appsv1.Deployment, error) {
 	d, err := f.NewDeployment(MustAssetReader(GrafanaDeployment))
 	if err != nil {
 		return nil, err
@@ -1379,6 +1393,17 @@ func (f *Factory) GrafanaDeployment() (*appsv1.Deployment, error) {
 		d.Spec.Template.Spec.Tolerations = f.config.GrafanaConfig.Tolerations
 	}
 
+	if proxyCABundleCM != nil {
+		volumeName := "grafana-trusted-ca-bundle"
+		d.Spec.Template.Spec.Containers[0].VolumeMounts = append(d.Spec.Template.Spec.Containers[0].VolumeMounts, trustedCABundleVolumeMount(volumeName, "/etc/pki/ca-trust/extracted/pem/"))
+		volume := trustedCABundleVolume(proxyCABundleCM.Name, volumeName)
+		volume.VolumeSource.ConfigMap.Items = append(volume.VolumeSource.ConfigMap.Items, v1.KeyToPath{
+			Key:  "ca-bundle.crt",
+			Path: "tls-ca-bundle.pem",
+		})
+		d.Spec.Template.Spec.Volumes = append(d.Spec.Template.Spec.Volumes, volume)
+	}
+
 	d.Namespace = f.namespace
 
 	return d, nil
