@@ -323,7 +323,12 @@ func TestUnconfiguredManifests(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	_, err = f.GrafanaDeployment()
+	_, err = f.GrafanaTrustedCABundle()
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	_, err = f.GrafanaDeployment(nil)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -368,6 +373,11 @@ func TestUnconfiguredManifests(t *testing.T) {
 		t.Fatal(err)
 	}
 
+	_, err = f.TelemeterClientDeployment(nil)
+	if err != nil {
+		t.Fatal(err)
+	}
+
 	_, err = f.TelemeterTrustedCABundle()
 	if err != nil {
 		t.Fatal(err)
